#!/bin/bash

# Restore environment variables (if there is anything to restore)
if [[ ! -z "${OMNISCI_ROOT_PATH_BACKUP+x}" ]]
then
  export OMNISCI_ROOT_PATH="${OMNISCI_ROOT_PATH_BACKUP}"
  unset OMNISCI_ROOT_PATH_BACKUP
fi

