

set -ex



test -f ${PREFIX}/lib/libDBEngine.so
test -f "${PREFIX}/etc/conda/activate.d/omniscidbe_activate.sh"
test -f "${PREFIX}/etc/conda/deactivate.d/omniscidbe_deactivate.sh"
source ${PREFIX}/etc/conda/activate.d/omniscidbe_activate.sh
test -n "${OMNISCI_ROOT_PATH+x}"
ldd ${PREFIX}/lib/libDBEngine.so

exit 0
