#!/bin/bash

# Backup environment variables (only if the variables are set)
if [[ ! -z "${OMNISCI_ROOT_PATH+x}" ]]
then
  export OMNISCI_ROOT_PATH_BACKUP="${OMNISCI_ROOT_PATH:-}"
fi

# OMNISCI_ROOT_PATH is requires for libDBEngine.so to determine the
# the omnisci root path correctly.
export OMNISCI_ROOT_PATH=${CONDA_PREFIX}/opt/omnisci

